==> unity-ads-4.9.3-sources.jar: com/unity3d/ads/core/domain/AndroidShow.kt <==
package com.unity3d.ads.core.domain

import android.content.Context
import com.unity3d.ads.adplayer.AndroidShowOptions
import com.unity3d.ads.core.configuration.GameServerIdReader
import com.unity3d.ads.core.data.model.AdObject
import com.unity3d.ads.core.data.model.ShowEvent
import com.unity3d.ads.core.data.repository.AdRepository
import kotlinx.coroutines.flow.*

class AndroidShow(
    private val adRepository: AdRepository,
    private val gameServerIdReader: GameServerIdReader,
    private val sendDiagnosticEvent: SendDiagnosticEvent,
) : Show {
    override fun invoke(context: Context, adObject: AdObject): Flow<ShowEvent> = flow {
        require(!adObject.opportunityId.isEmpty) { "No opportunityId" }

        val opportunityId = adObject.opportunityId

        val ad = adRepository.getAd(opportunityId) ?: throw IllegalStateException("No ad associated with opportunityId")

        sendDiagnosticEvent(event = SendDiagnosticEvent.SHOW_STARTED_AD_VIEWER)

        ad.adPlayer.onShowEvent
            .onStart {
                ad.playerServerId = gameServerIdReader.readAndDelete(null)
                ad.adPlayer.show(AndroidShowOptions(context))
            }
            .onCompletion { adRepository.removeAd(opportunityId) }
            .transformWhile {
                emit(it)
                it !is ShowEvent.Completed && it !is ShowEvent.Error
            }
            .collect { emit(it) }
    }

    override suspend fun terminate(adObject: AdObject) {
        adObject.adPlayer.destroy()
    }
}

==> unity-ads-4.11.0-sources.jar: com/unity3d/ads/core/domain/AndroidShow.kt <==
package com.unity3d.ads.core.domain

import android.content.Context
import com.unity3d.ads.UnityAdsShowOptions
import com.unity3d.ads.adplayer.AndroidShowOptions
import com.unity3d.ads.core.configuration.GameServerIdReader
import com.unity3d.ads.core.data.model.AdObject
import com.unity3d.ads.core.data.model.ShowEvent
import com.unity3d.ads.core.data.repository.AdRepository
import com.unity3d.ads.core.extensions.toMap
import kotlinx.coroutines.flow.*
import org.koin.core.annotation.Single

@Single
class AndroidShow(
    private val adRepository: AdRepository,
    private val gameServerIdReader: GameServerIdReader,
    private val sendDiagnosticEvent: SendDiagnosticEvent,
) : Show {
    override fun invoke(context: Context, adObject: AdObject, showOptions: UnityAdsShowOptions): Flow<ShowEvent> = flow {
        require(!adObject.opportunityId.isEmpty) { "No opportunityId" }

        val opportunityId = adObject.opportunityId

        val ad = adRepository.getAd(opportunityId) ?: throw IllegalStateException("No ad associated with opportunityId")

        sendDiagnosticEvent(event = SendDiagnosticEvent.SHOW_STARTED_AD_VIEWER, adObject = adObject)

        val adPlayer = ad.adPlayer ?: throw IllegalStateException("No adPlayer associated with ad")

        adPlayer.onShowEvent
            .onStart {
                ad.playerServerId = gameServerIdReader.readAndDelete(null)
                ad.adPlayer.show(AndroidShowOptions(context, showOptions.data?.toMap()))
            }
            .onCompletion { adRepository.removeAd(opportunityId) }
            .transformWhile {
                emit(it)
                it !is ShowEvent.Completed && it !is ShowEvent.Error
            }
            .collect { emit(it) }
    }

    override suspend fun terminate(adObject: AdObject) {
        adObject.adPlayer?.destroy()
    }
}
